@@ -1,38 +1,47 @@
 /*
-copyright 2002 Alexander Malmberg <alexander@malmberg.org>
-*/
+ *
+ * Copyright 2002 Alexander Malmberg <alexander@malmberg.org>
+ *           2012 The Free Software Foundation
+ *
+ * Authors: Alexander Malmberg <alexander@malmberg.org>
+ *          Riccardo Mottola <rm@gnu.org>
+ *
+ */
 
 #include <math.h>
 
-#include <Foundation/NSObject.h>
-#include <Foundation/NSValue.h>
-#include <Foundation/NSBundle.h>
-#include <Foundation/NSUserDefaults.h>
-#include <Foundation/NSInvocation.h>
-#include <AppKit/NSWindow.h>
-#include <AppKit/NSScrollView.h>
-#include <AppKit/NSTableView.h>
-#include <AppKit/NSTableColumn.h>
-#include <AppKit/NSSplitView.h>
-#include <AppKit/NSTextView.h>
-#include <AppKit/NSTextContainer.h>
-#include <AppKit/NSClipView.h>
-#include <AppKit/NSCell.h>
-#include <AppKit/NSFont.h>
+#import <Foundation/NSObject.h>
+#import <Foundation/NSValue.h>
+#import <Foundation/NSBundle.h>
+#import <Foundation/NSUserDefaults.h>
+#import <Foundation/NSInvocation.h>
+#import <Foundation/NSString.h>
+#import <AppKit/NSWindow.h>
+#import <AppKit/NSScrollView.h>
+#import <AppKit/NSTableView.h>
+#import <AppKit/NSTableColumn.h>
+#import <AppKit/NSSplitView.h>
+#import <AppKit/NSTextView.h>
+#import <AppKit/NSTextContainer.h>
+#import <AppKit/NSClipView.h>
+#import <AppKit/NSCell.h>
+#import <AppKit/NSFont.h>
+#import <AppKit/NSEvent.h>
+#import <AppKit/NSStringDrawing.h>
 
-#include <Pantomime/MimeUtility.h>
+#import <Pantomime/CWMIMEUtility.h>
 
-#include "MsgDB.h"
+#import "MsgDB.h"
 
-#include "FolderWindowController.h"
+#import "FolderWindowController.h"
 
-#include "FolderThreader.h"
+#import "FolderThreader.h"
 
-#include "KeyWindow.h"
-#include "MessageViewController.h"
-#include "main.h"
+#import "KeyWindow.h"
+#import "MessageViewController.h"
+#import "main.h"
 
-#include "Pref_ReadAhead.h"
+#import "Pref_ReadAhead.h"
 
 
 #define SORT_THREAD          0
