@@ -6,7 +6,7 @@ copyright 2002 Alexander Malmberg <alexander@malmberg.org>
 #define MessageViewController_h
 
 @class NSTextView,NSScrollView,NSMutableDictionary;
-@class Message;
+@class CWMessage;
 
 #include "MsgDB.h"
 
@@ -17,7 +17,7 @@ copyright 2002 Alexander Malmberg <alexander@malmberg.org>
 
 	MsgDB *mdb;
 	msg_id_t mid;
-	Message *cur_message;
+	CWMessage *cur_message;
 
 	/* actually an NSMapTable */
 	void *cur_options;
@@ -48,6 +48,8 @@ copyright 2002 Alexander Malmberg <alexander@malmberg.org>
 
 -(void) messageSave;
 
+-(void) encodingChanged: (NSNotification *)n;
+
 @end
 
 #endif
