@@ -1,36 +1,46 @@
 /*
-copyright 2002 Alexander Malmberg <alexander@malmberg.org>
-*/
+ *
+ * Copyright 2002 Alexander Malmberg <alexander@malmberg.org>
+ *           2012 The Free Software Foundation
+ *
+ * Authors: Alexander Malmberg <alexander@malmberg.org>
+ *          Riccardo Mottola <rm@gnu.org>
+ *
+ */
 
-#include <Foundation/NSObject.h>
-#include <Foundation/NSBundle.h>
-#include <Foundation/NSFileManager.h>
-#include <AppKit/NSFileWrapper.h>
-#include <AppKit/NSTextView.h>
-#include <AppKit/NSScrollView.h>
-#include <AppKit/NSClipView.h>
-#include <AppKit/NSTextStorage.h>
-#include <AppKit/NSFont.h>
-#include <AppKit/NSLayoutManager.h>
-#include <AppKit/NSSavePanel.h>
+#import <Foundation/NSObject.h>
+#import <Foundation/NSBundle.h>
+#import <Foundation/NSFileManager.h>
+#import <Foundation/NSString.h>
+#import <AppKit/NSAttributedString.h>
+#import <AppKit/NSGraphics.h>
+#import <AppKit/NSGraphicsContext.h>
+#import <AppKit/NSFileWrapper.h>
+#import <AppKit/NSTextView.h>
+#import <AppKit/NSScrollView.h>
+#import <AppKit/NSClipView.h>
+#import <AppKit/NSTextStorage.h>
+#import <AppKit/NSFont.h>
+#import <AppKit/NSLayoutManager.h>
+#import <AppKit/NSSavePanel.h>
 
-#include "MessageViewController.h"
+#import "MessageViewController.h"
 
-#include "Pref_MessageViewing.h"
-#include "main.h"
+#import "Pref_MessageViewing.h"
+#import "main.h"
 
-#include "GUISource.h"
+#import "GUISource.h"
 
-#include <Pantomime/Message.h>
-#include <Pantomime/MimeMultipart.h>
-#include <Pantomime/MimeUtility.h>
-#include <Pantomime/InternetAddress.h>
-#include <Pantomime/UUFile.h>
+#import <Pantomime/CWMessage.h>
+#import <Pantomime/CWMIMEMultipart.h>
+#import <Pantomime/CWMIMEUtility.h>
+#import <Pantomime/CWInternetAddress.h>
+#import <Pantomime/CWUUFile.h>
 
 //#define USE_MIME_STUFF
 
 #ifdef USE_MIME_STUFF
-#include <Mime/Mime.h>
+#import <Mime/Mime.h>
 
 static MimeManager *mime_manager;
 #endif
@@ -89,7 +99,7 @@ static int get_depth(NSString *t,int start,int end)
 
 
 @interface MessageViewController (private)
--(void) _renderContent:(id)p  parent:(Part *)parent  to:(NSMutableAttributedString *)str;
+-(void) _renderContent:(id)p  parent:(CWPart *)parent  to:(NSMutableAttributedString *)str;
 -(void) _renderPart:(id)p to:(NSMutableAttributedString *)str;
 
 -(void) displayMessage;
@@ -212,10 +222,10 @@ static void appendPlainText(NSMutableAttributedString *str,
 }
 
 
--(void) _render_multipart: (MimeMultipart *)mp  type: (NSString *)ct
+-(void) _render_multipart: (CWMIMEMultipart *)mp  type: (NSString *)ct
 	to: (NSMutableAttributedString *)str
 {
-	Part *bp;
+	CWPart *bp;
 	int i;
 
 	if ([ct isEqual: @"multipart/alternative"])
@@ -227,14 +237,14 @@ static void appendPlainText(NSMutableAttributedString *str,
 		else
 			disp=[mp count]-1;
 
-		bp=[mp bodyPartAtIndex: disp];
+		bp=[mp partAtIndex: disp];
 		append(str,header_bold_dict,_(@"Currently shown:"));
 		append(str,header_dict,@" %@\n",[bp contentType]);
 		append(str,header_bold_dict,_(@"Alternatives:"));
 		for (i=0;i<[mp count];i++)
 		{
 			appendLink(str,LINK_MULTIPART_ALTERNATIVE,mp,i+1,@" %@",
-				[[mp bodyPartAtIndex: i] contentType]);
+				[[mp partAtIndex: i] contentType]);
 		}
 		append(str,nil,@"\n");
 
@@ -249,7 +259,7 @@ static void appendPlainText(NSMutableAttributedString *str,
 
 		for (i=0;i<[mp count];i++)
 		{
-			bp=[mp bodyPartAtIndex: i];
+			bp=[mp partAtIndex: i];
 			append(str,header_bold_dict,_(@"\nPart:"));
 			append(str,header_dict,@" %i %@\n",i,[bp contentType]);
 			[self _renderPart:bp to:str];
@@ -264,7 +274,7 @@ static void appendPlainText(NSMutableAttributedString *str,
 	NSDictionary *fd;
 	NSFont *f;
 
-	NSRange r;
+	//	NSRange r;
 
 	if (cur_font)
 		f=[Pref_MessageViewing font2];
@@ -276,7 +286,7 @@ static void appendPlainText(NSMutableAttributedString *str,
 
 #if 0 /* TODO: need to update with new Pantomime interface */
 	/* TODO: this should probably be optional */
-	r=[MimeUtility rangeOfUUEncodedStringFromString: text
+	r=[CWMIMEUtility rangeOfUUEncodedStringFromString: text
 		range: NSMakeRange(0,[text length])];
 
 	if (r.location==NSNotFound)
@@ -291,7 +301,7 @@ static void appendPlainText(NSMutableAttributedString *str,
 			appendPlainText(str,fd,[text substringWithRange: NSMakeRange(0,r.location)]);
 
 		/* TODO: this is inefficient */
-		fw=[MimeUtility fileWrapperFromUUEncodedString: [text substringWithRange: r]];
+		fw=[CWMIMEUtility fileWrapperFromUUEncodedString: [text substringWithRange: r]];
 
 		append(str,header_bold_dict,_(@"UUEncoded file:"));
 		append(str,header_dict,@" %@    ",[fw preferredFilename]);
@@ -312,7 +322,7 @@ static void appendPlainText(NSMutableAttributedString *str,
 }
 
 
--(void) _renderContent:(id)p  parent:(Part *)parent
+-(void) _renderContent:(id)p  parent:(CWPart *)parent
 	to:(NSMutableAttributedString *)str
 {
 	NSString *ct=[parent contentType];
@@ -340,9 +350,9 @@ static void appendPlainText(NSMutableAttributedString *str,
 
 
 	/* Some content classes/types we handle internally. */
-	if ([p isKindOfClass: [MimeMultipart class]])
+	if ([p isKindOfClass: [CWMIMEMultipart class]])
 	{
-		[self _render_multipart: (MimeMultipart *)p  type: ct  to: str];
+		[self _render_multipart: (CWMIMEMultipart *)p  type: ct  to: str];
 		return;
 	}
 
@@ -352,7 +362,7 @@ static void appendPlainText(NSMutableAttributedString *str,
 		return;
 	}
 
-	if ([p isKindOfClass: [Part class]])
+	if ([p isKindOfClass: [CWPart class]])
 	{
 		[self _renderPart: p to: str];
 		return;
@@ -553,13 +563,13 @@ static void appendPlainText(NSMutableAttributedString *str,
 
 -(void) _renderPart:(id)p to:(NSMutableAttributedString *)str
 {
-	if ([p isKindOfClass: [Message class]])
+	if ([p isKindOfClass: [CWMessage class]])
 	{
-		Message *m=(Message *)p;
+		CWMessage *m=(CWMessage *)p;
 		append(str,header_bold_dict,_(@"Subject:"));
 		append(str,header_dict,@" %@\n",[m subject]);
 		append(str,header_bold_dict,_(@"From:"));
-		append(str,header_dict,@" %@\n",[[m from] unicodeStringValue]);
+		append(str,header_dict,@" %@\n",[[m from] stringValue]);
 		append(str,header_bold_dict,_(@"Newsgroups:"));
 		append(str,header_dict,@" %@\n",[m headerValueForName: @"Newsgroups"]);
 		append(str,header_bold_dict,_(@"Date:"));
@@ -569,9 +579,9 @@ static void appendPlainText(NSMutableAttributedString *str,
 		append(str,nil,@"\n");
 		[self _renderContent:[m content] parent: m to:str];
 	}
-	else if ([p isKindOfClass: [Part class]])
+	else if ([p isKindOfClass: [CWPart class]])
 	{ /* handles MimeBodyPart and any extensions */
-		[self _renderContent:[(Part *)p content] parent: (Part *)p to:str];
+		[self _renderContent:[(CWPart *)p content] parent: (CWPart *)p to:str];
 	}
 	else
 	{
@@ -655,7 +665,27 @@ changes */
 		NSData *d;
 
 		d=[[NSData alloc] initWithBytes: data length: length];
-		cur_message=[(Message *)[Message alloc] initWithData: d];
+		if([mdb msg_getHeader: "ContentType" : mid])
+		  {
+		    cur_message=[(CWMessage *)[CWMessage alloc] initWithData: d];
+		  }
+		else
+		  {
+		    cur_message=[(CWMessage *)[CWMessage alloc] initWithData: d
+					      charset:[Pref_MessageViewing defaultEncoding]];
+		  }
+		if(![cur_message contentType])
+		  {
+		    [cur_message setContentType:@"text/plain"];
+		  }
+		else
+		  {
+		    ASSIGN(
+			   cur_message,
+			   [(CWMessage *)[CWMessage alloc] initWithData: d
+					 charset:[cur_message charset]]
+			   );
+		  }
 		[d release];
 
 		{
@@ -815,21 +845,21 @@ changes */
 		NSData *d;
 		NSString *filename;
 
-		if ([l->object isKindOf: [NSString class]])
+		if ([l->object isKindOfClass: [NSString class]])
 		{
 			NSString *s=(NSString *)l->object;
 			NSRange r;
-			UUFile *fw;
-			r=[MimeUtility rangeOfUUEncodedStringFromString: s
+			CWUUFile *fw;
+			r=[CWUUFile rangeOfUUEncodedStringFromString: s
 				range: NSMakeRange(0,[s length])];
 
-			fw=[MimeUtility fileFromUUEncodedString: [s substringWithRange: r]];
+			fw=[CWUUFile fileFromUUEncodedString: [s substringWithRange: r]];
 			filename=AUTORELEASE(RETAIN([fw name]));
 			d=AUTORELEASE(RETAIN([fw data]));
 		}
 		else
 		{
-			Part *p=(Part *)l->object;
+			CWPart *p=(CWPart *)l->object;
 			d=(NSData *)[p content];
 			filename=[p filename];
 		}
@@ -926,6 +956,12 @@ changes */
 
 	mid=0;
 
+	[[NSNotificationCenter defaultCenter]
+	  addObserver: self
+	  selector: @selector(encodingChanged:)
+	  name: DefaultEncodingChangedNotification
+	  object: nil];
+
 	return self;
 }
 
@@ -1154,6 +1190,11 @@ changes */
 	[app_delegate composeFollowupToMessage: cur_message];
 }
 
+-(void) encodingChanged: (NSNotification *)n
+{
+  [self getData];
+  [self displayMessage];
+}
 
 @end
 
