@@ -1,5 +1,6 @@
 /*
 copyright 2002 Alexander Malmberg <alexander@malmberg.org>
+          2012 Riccardo Mottola <rm@gnu.org>
 */
 
 /*
@@ -18,6 +19,7 @@ cleanups, better organization
 #include <Foundation/NSAutoreleasePool.h>
 #include <Foundation/NSNotification.h>
 #include <Foundation/NSData.h>
+#import <Foundation/NSDictionary.h>
 
 #include "MsgDB.h"
 
@@ -340,7 +342,7 @@ static inline unsigned int hash_id(const char *mid)
 
 //			fprintf(stderr,"got '%s' type '%s'\n",buf,[self msg_getMetaHeader: "Type" : mid]);
 
-			c=objc_lookup_class([self msg_getMetaHeader: "Type" : mid]);
+			c=objc_lookUpClass([self msg_getMetaHeader: "Type" : mid]);
 			n=[[NSNumber alloc] initWithInt: i];
 			src=[[c alloc] initWithMsg: mid db: self];
 			[sources setObject: src forKey: n];
@@ -667,20 +669,20 @@ static inline unsigned int hash_id(const char *mid)
 	fprintf(f,"%i\n",num_meta_headers);
 	for (i=0;i<num_meta_headers;i++)
 	{
-		fprintf(f,"%i ",strlen(meta_headers[i]));
+          fprintf(f,"%i ",(int)strlen(meta_headers[i]));
 		fwrite(meta_headers[i],1,strlen(meta_headers[i]),f);
 		fputc('\n',f);
 	}
 	fprintf(f,"%i\n",num_messages);
 	for (i=1,m=messages+1;i<num_messages;i++,m++)
 	{
-		fprintf(f,"%i %i ",m->num_mhs,strlen(m->message_id));
+          fprintf(f,"%i %i ",m->num_mhs,(int)strlen(m->message_id));
 		fwrite(m->message_id,1,strlen(m->message_id),f);
 		fputc('\n',f);
 		for (j=0;j<m->num_mhs;j++)
 		{
-			fprintf(f,"%i %i ",m->mhs[j].mhid,strlen(m->mhs[j].value));
-			fwrite(m->mhs[j].value,1,strlen(m->mhs[j].value),f);
+                  fprintf(f,"%i %i ",m->mhs[j].mhid,(int)strlen(m->mhs[j].value));
+                  fwrite(m->mhs[j].value,1,strlen(m->mhs[j].value),f);
 			fputc('\n',f);
 		}
 	}
