@@ -1,5 +1,6 @@
 /*
 copyright 2001-2002 Alexander Malmberg <alexander@malmberg.org>
+          2015 Riccardo Mottola
 */
 
 #include <stdio.h>
@@ -740,7 +741,7 @@ static int num_group_names;
 			memcpy(cn->resp_msg,b,c-b);
 			cn->resp_msg[c-b]=0;
 		}
-		cn->resp_code=atoi(cn->resp_buf);
+		cn->resp_code=atoi((const char *)(cn->resp_buf));
 		c+=2;
 		if (c==e)
 			cn->resp_buf_len=0;
@@ -813,13 +814,13 @@ static int num_group_names;
 	{
 		if (cn->resp_data_len>48*1024)
 		{
-			char **list;
+			unsigned char **list;
 			int num;
 			unsigned char *b,*d,*e;
 
 			num=0;
 			/* TODO: this will be excessively large almost all the time */
-			list=malloc(sizeof(char *)*(cn->cur.d.range.h-cn->cur.d.range.l+1));
+			list=malloc(sizeof(unsigned char *)*(cn->cur.d.range.h-cn->cur.d.range.l+1));
 			d=b=cn->resp_buf;
 			/* always leave at least one byte so there will be a final
 			non-partial call to nntp_headerRange:... */
@@ -843,10 +844,10 @@ static int num_group_names;
 #endif
 
 			[rec nntp_headerRange:
-				cn->cur.d.range.group :
-				cn->cur.d.range.l : cn->cur.d.range.h : num : list
-				partial: YES
-				qid: cn->cur.qid];
+			       cn->cur.d.range.group :
+			       cn->cur.d.range.l : cn->cur.d.range.h : num : (char **)list
+			     partial: YES
+			     qid: (unsigned int)cn->cur.qid];
 
 			free(list);
 
@@ -1047,7 +1048,7 @@ extern int vasprintf(char **c,const char *format,va_list args); /* TODO? */
 	c->write_pending=NULL;
 
 	c->write_len=length;
-	c->write_pending=data;
+	c->write_pending=(char *)data;
 	c->write_pending_ofs=0;
 
 #ifdef DEBUG_SOCKET
@@ -1251,9 +1252,9 @@ extern int vasprintf(char **c,const char *format,va_list args); /* TODO? */
 			break;
 		case S_HEADER_RANGE2:
 		{
-			char **list;
+			unsigned char **list;
 			int num;
-			char *b,*d,*e;
+			unsigned char *b,*d,*e;
 
 			num=0;
 			list=malloc(sizeof(char *)*(q->d.range.h-q->d.range.l+1));
@@ -1279,9 +1280,9 @@ extern int vasprintf(char **c,const char *format,va_list args); /* TODO? */
 			{
 				[rec nntp_headerRange:
 					q->d.range.group :
-					q->d.range.l : q->d.range.h : num : list
+				       q->d.range.l : q->d.range.h : num : (char **)list
 					partial: NO
-					qid: q->qid];
+				     qid: (unsigned int)q->qid];
 			}
 
 			free(list);
